# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
✨ Updated at for Well | [48](https://github.com/laminlabs/wetlab/pull/48) | [sunnyosun](https://github.com/sunnyosun) | 2024-04-25 |
🚚 Rename lnschema-lamin1 to wetlab | [47](https://github.com/laminlabs/wetlab/pull/47) | [sunnyosun](https://github.com/sunnyosun) | 2024-03-08 | 0.27.0
🔥 Temporarily remove a few biosample fields | [45](https://github.com/laminlabs/wetlab/pull/45) | [sunnyosun](https://github.com/sunnyosun) | 2024-02-07 | 0.26.0
🚚 Rename `Dataset` to `Collection` | [44](https://github.com/laminlabs/wetlab/pull/44) | [falexwolf](https://github.com/falexwolf) | 2024-01-02 | 0.25.0
🚚 Rename `File` to `Artifact` | [43](https://github.com/laminlabs/wetlab/pull/43) | [falexwolf](https://github.com/falexwolf) | 2023-12-12 | 0.24.0
📝 Prettify docstrings | [42](https://github.com/laminlabs/wetlab/pull/42) | [falexwolf](https://github.com/falexwolf) | 2023-11-14 |
⬆️ Upgrade lamindb | [41](https://github.com/laminlabs/wetlab/pull/41) | [fredericenard](https://github.com/fredericenard) | 2023-11-11 | 0.23.8
♻️ Add CanValidate | [40](https://github.com/laminlabs/wetlab/pull/40) | [falexwolf](https://github.com/falexwolf) | 2023-11-06 | 0.23.7
⬆️ Update to lamindb 0.58.2 | [39](https://github.com/laminlabs/wetlab/pull/39) | [sunnyosun](https://github.com/sunnyosun) | 2023-10-27 |
🚚 Rename species to organism | [38](https://github.com/laminlabs/wetlab/pull/38) | [sunnyosun](https://github.com/sunnyosun) | 2023-10-19 | 0.23.5
⬆️ Upgrade lamindb | [37](https://github.com/laminlabs/wetlab/pull/37) | [fredericenard](https://github.com/fredericenard) | 2023-10-18 | 0.23.3
🚚 Migrate to integer primary keys | [36](https://github.com/laminlabs/wetlab/pull/36) | [falexwolf](https://github.com/falexwolf) | 2023-10-13 |
⬆️ Upgrade to lamindb 0.55 | [35](https://github.com/laminlabs/wetlab/pull/35) | [sunnyosun](https://github.com/sunnyosun) | 2023-10-03 | 0.23.2
🎨 Add test and trigger | [34](https://github.com/laminlabs/wetlab/pull/34) | [falexwolf](https://github.com/falexwolf) | 2023-09-29 |
🚚 Rename PlateWell to Well | [33](https://github.com/laminlabs/wetlab/pull/33) | [sunnyosun](https://github.com/sunnyosun) | 2023-09-18 | 0.23.1
🎨 Autogenerated primary key for PlateWell | [32](https://github.com/laminlabs/wetlab/pull/32) | [sunnyosun](https://github.com/sunnyosun) | 2023-09-18 | 0.23.0
⬆️ Upgrade to lamindb 0.51 | [31](https://github.com/laminlabs/wetlab/pull/31) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-25 |
⬆️ Upgrade lamindb | [30](https://github.com/laminlabs/wetlab/pull/30) | [fredericenard](https://github.com/fredericenard) | 2023-08-04 |
⬆️ Update to lamindb 0.49 | [29](https://github.com/laminlabs/wetlab/pull/29) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-31 | 0.22.1
⬆️ Lamindb 0.48a2 | [28](https://github.com/laminlabs/wetlab/pull/28) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-21 |
🔥 Remove altos instance delopyment | [27](https://github.com/laminlabs/wetlab/pull/27) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-20 |
🚚 Rename Well to PlateWell | [26](https://github.com/laminlabs/wetlab/pull/26) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-11 | 0.21.0
⬆️ Upgrade to lamindb 0.47 | [25](https://github.com/laminlabs/wetlab/pull/25) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-11 | 0.20.4
🍱 Added description to tables, change DateTime to Date field | [24](https://github.com/laminlabs/wetlab/pull/24) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-06 | 0.20.3
🏷️ Change target to targets in Treatment | [23](https://github.com/laminlabs/wetlab/pull/23) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-05 |
🐛 Fix related names of TreatmentTarget | [22](https://github.com/laminlabs/wetlab/pull/22) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-04 |
✨ Added TreatmentTarget | [21](https://github.com/laminlabs/wetlab/pull/21) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-04 |
🐛 Fix non-required fields | [20](https://github.com/laminlabs/wetlab/pull/20) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-03 |
✨ Added target_genes | [19](https://github.com/laminlabs/wetlab/pull/19) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-03 |
🚚 Rename `BaesORM` to `ORM` | [18](https://github.com/laminlabs/wetlab/pull/18) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-02 |
⬆️ Upgrade to 0.45.0 | [17](https://github.com/laminlabs/wetlab/pull/17) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-30 | 0.19.2
⬆️ Bump lamindb to 0.44.0 | [16](https://github.com/laminlabs/wetlab/pull/16) | [falexwolf](https://github.com/falexwolf) | 2023-06-21 | 0.19.0
👷 Add app deploy workflow | [15](https://github.com/laminlabs/wetlab/pull/15) | [falexwolf](https://github.com/falexwolf) | 2023-06-20 | 0.19a3
⬆️ Bump lamindb to 0.43.0 | [14](https://github.com/laminlabs/wetlab/pull/14) | [fredericenard](https://github.com/fredericenard) | 2023-06-19 | 0.19a2
♻️ Prettify | [13](https://github.com/laminlabs/wetlab/pull/13) | [falexwolf](https://github.com/falexwolf) | 2023-06-12 | 0.19a1
🚚 Migrate to Django (2) | [12](https://github.com/laminlabs/wetlab/pull/12) | [falexwolf](https://github.com/falexwolf) | 2023-06-11 |
🚚 Migrate to Django (1) | [11](https://github.com/laminlabs/wetlab/pull/11) | [falexwolf](https://github.com/falexwolf) | 2023-06-09 |
🏗️ Remove `lnbase-biolab` | [10](https://github.com/laminlabs/wetlab/pull/10) | [falexwolf](https://github.com/falexwolf) | 2023-06-01 | 0.18a1
🏗️ Remove SQL-level schema modules | [9](https://github.com/laminlabs/wetlab/pull/9) | [falexwolf](https://github.com/falexwolf) | 2023-05-25 | 0.17.0
🎨 Add `Well` table, `File.cell_lines` | [8](https://github.com/laminlabs/wetlab/pull/8) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-23 | 0.16.3
💚 Removed `Treatment` relationships | [4](https://github.com/laminlabs/wetlab/pull/4) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-15 | 0.16.2
✨ Added `Treatment` | [3](https://github.com/laminlabs/wetlab/pull/3) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-15 |
🚚 Link `CellType` to `File` | [2](https://github.com/laminlabs/wetlab/pull/2) | [falexwolf](https://github.com/falexwolf) | 2023-04-24 | 0.16.1
🎉 Move content from `lnschema-wetlab` here | [1](https://github.com/laminlabs/wetlab/pull/1) | [falexwolf](https://github.com/falexwolf) | 2023-04-22 | 0.15.1
